@@ -8,6 +8,56 @@ from selenium import webdriver
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 import time
 
+def volatilidade(__ticker, **kwargs):
+    """
+        Busca no site da B3 a volatilidade histórica de um ativo
+
+        :param __ticker: código do ativo
+        :param __periodo = x, x em meses (1, 3, 6, 12). Padrão = 6 meses
+        :return: tuple [ticker, nome de pregão, cotacao, horario, variação monetária, variação percentual
+        """
+
+    caps = DesiredCapabilities().CHROME
+    caps["pageLoadStrategy"] = "eager"  # interactive
+    options = webdriver.ChromeOptions()
+    chrome_preferences = {'profile.managed_default_content_settings.images': 2}
+    options.add_argument("headless")
+    # noinspection SpellCheckingInspection
+    options.add_experimental_option("prefs", chrome_preferences)
+    browser = webdriver.Chrome(options=options, service_args=['--silent'], desired_capabilities=caps)
+
+    try:
+        __periodo = [int(kwargs.get('periodo'))]
+        if '|1|3|6|12|'.find('|'+str([__periodo])+'|') == -1:
+            __periodo = [6]
+    except:
+        __periodo = [1,3,6,12]
+    __result = []
+    for __item in __periodo:
+        if __periodo == 1:
+            __periodo_text = '12Meses'
+        elif __periodo == 12:
+            __periodo_text = '1Ano'
+        else:
+            __periodo_txt = __periodo + 'Meses'
+        # noinspection SpellCheckingInspection
+        url = 'http://bvmf.bmfbovespa.com.br/cias-listadas/volatilidade-ativos/ResumoVolatilidadeAtivos.aspx?' \
+              'metodo=padrao&' \
+              'periodo=' + __periodo_txt + '&' \
+              'codigo=' + __ticker + '&' \
+              'idioma=pt'
+        browser.get(url)
+        html = browser.page_source
+        soup = BeautifulSoup(html, "lxml")
+        td_list = soup.find_all('td')
+        try:
+            __result.append([float(td_list[3].text.replace(",", ".")),float(td_list[4].text.replace(",", "."))])
+        except:
+            __result.append(['', ''])
+    return __result
+
+
+
 def ultima_cotacao(__ticker, **kwargs):
     """
     Busca no site Tradingview.com o nome de pregão de um ativo, a última cotação, seu horário,
